@@ -146,12 +146,12 @@ class ProjectDataStore(JsonDataStore, UpdateInterface):
         """Prevent calling JsonDataStore set() method. It is not allowed in ProjectDataStore, as changes come from UpdateManager."""
         raise RuntimeError("ProjectDataStore.set() is not allowed. Changes must route through UpdateManager.")
 
-    def _set(self, key, values=None, add=False, partial_update=False, remove=False):
+    def _set(self, key, values=None, add=False, remove=False):
         """ Store setting, but adding isn't allowed. All possible settings must be in default settings file. """
 
         log.debug(
-            "_set key: %s values: %s add: %s partial: %s remove: %s",
-            key, values, add, partial_update, remove)
+            "_set key: %s, values: %s, add: %s, remove: %s",
+            key, values, add, remove)
         parent, my_key = None, ""
 
         # Verify key is valid type
@@ -285,33 +285,18 @@ class ProjectDataStore(JsonDataStore, UpdateInterface):
 
         # Get default profile
         s = get_app().get_settings()
-        default_profile = s.get("default-profile")
+        default_profile_desc = s.get("default-profile")
 
-        # Loop through profiles
-        profile_dirs = [info.USER_PROFILES_PATH, info.PROFILES_PATH]
-        available_dirs = [f for f in profile_dirs if os.path.exists(f)]
-        for profile_folder in available_dirs:
-            for file in os.listdir(profile_folder):
-                profile_path = os.path.join(profile_folder, file)
-                try:
-                    # Load Profile and append description
-                    profile = openshot.Profile(profile_path)
+        # Get profile (if any)
+        profile = self.get_profile(profile_desc=default_profile_desc)
+        if not profile:
+            # Fallback, in case of missing/invalid default profile
+            profile = self.get_profile(profile_desc="HD 720p 30 fps")
 
-                    if default_profile == profile.info.description:
-                        log.info("Setting default profile to %s" % profile.info.description)
-
-                        # Update default profile
-                        self._data["profile"] = profile.info.description
-                        self._data["width"] = profile.info.width
-                        self._data["height"] = profile.info.height
-                        self._data["fps"] = {"num": profile.info.fps.num, "den": profile.info.fps.den}
-                        self._data["display_ratio"] = {"num": profile.info.display_ratio.num, "den": profile.info.display_ratio.den}
-                        self._data["pixel_ratio"] = {"num": profile.info.pixel_ratio.num, "den": profile.info.pixel_ratio.den}
-                        break
-
-                except RuntimeError as e:
-                    # This exception occurs when there's a problem parsing the Profile file - display a message and continue
-                    log.error("Failed to parse file '%s' as a profile: %s" % (profile_path, e))
+        # Update default profile (if it changed)
+        if profile and default_profile_desc != profile.info.description:
+            log.info(f"Updating default-profile from legacy `{default_profile_desc}` to `{profile.info.description}`.")
+            s.set("default-profile", profile.info.description)
 
         # Apply default audio playback settings to this data structure
         self.apply_default_audio_settings()
@@ -319,6 +304,64 @@ class ProjectDataStore(JsonDataStore, UpdateInterface):
         # Set default project ID
         self._data["id"] = self.generate_id()
 
+    def get_profile(self, profile_desc=None, profile_key=None):
+        """Attempt to find a specific profile"""
+        profile = None
+
+        # Loop through legacy profiles
+        LEGACY_PROFILE_PATH = os.path.join(info.PROFILES_PATH, "legacy")
+        legacy_profile = None
+        for legacy_filename in os.listdir(LEGACY_PROFILE_PATH):
+            legacy_profile_path = os.path.join(LEGACY_PROFILE_PATH, legacy_filename)
+            try:
+                # Load Profile and append description
+                temp_profile = openshot.Profile(legacy_profile_path)
+                if profile_desc == temp_profile.info.description:
+                    legacy_profile = temp_profile
+                    break
+            except RuntimeError:
+                # Ignore legacy parsing errors
+                pass
+
+        # Loop through profiles
+        profile_dirs = [info.USER_PROFILES_PATH, info.PROFILES_PATH]
+        available_dirs = [f for f in profile_dirs if os.path.exists(f)]
+        for profile_folder in available_dirs:
+            for file in reversed(sorted(os.listdir(profile_folder))):
+                profile_path = os.path.join(profile_folder, file)
+                if os.path.isdir(profile_path):
+                    continue
+                try:
+                    # Load Profile and append description
+                    temp_profile = openshot.Profile(profile_path)
+
+                    if profile_desc == temp_profile.info.description:
+                        profile = self.apply_profile(temp_profile)
+                        break
+                    if legacy_profile and legacy_profile.Key() == temp_profile.Key():
+                        # Switch from legacy profile to new profile
+                        profile = self.apply_profile(temp_profile)
+                        break
+
+                except RuntimeError as e:
+                    # This exception occurs when there's a problem parsing the Profile file - display a message and continue
+                    log.error("Failed to parse file '%s' as a profile: %s" % (profile_path, e))
+
+        return profile
+
+    def apply_profile(self, profile):
+        """Apply a specific profile to the current project data"""
+        log.info("Setting profile to %s" % profile.info.description)
+
+        # Update default profile
+        self._data["profile"] = profile.info.description
+        self._data["width"] = profile.info.width
+        self._data["height"] = profile.info.height
+        self._data["fps"] = {"num": profile.info.fps.num, "den": profile.info.fps.den}
+        self._data["display_ratio"] = {"num": profile.info.display_ratio.num, "den": profile.info.display_ratio.den}
+        self._data["pixel_ratio"] = {"num": profile.info.pixel_ratio.num, "den": profile.info.pixel_ratio.den}
+        return profile
+
     def load(self, file_path, clear_thumbnails=True):
         """ Load project from file """
 
@@ -386,6 +429,13 @@ class ProjectDataStore(JsonDataStore, UpdateInterface):
             # Upgrade any data structures
             self.upgrade_project_data_structures()
 
+            # Get profile (if any)
+            project_profile_desc = self._data.get("profile", "HD 720p 30 fps")
+            profile = self.get_profile(profile_desc=project_profile_desc)
+            if not profile:
+                # Fallback, in case of missing/invalid default profile
+                profile = self.get_profile(profile_desc="HD 720p 30 fps")
+
             # Apply default audio playback settings to this data structure
             self.apply_default_audio_settings()
 
@@ -721,10 +771,7 @@ class ProjectDataStore(JsonDataStore, UpdateInterface):
                         self.is_keyframe_valid(crop_height, 1.0),
                        ]):
                     # Apply crop effect to clip (which wasn't available in 2.5.x)
-                    log.info(
-                        "Migrating OpenShot 2.5 crop properties for clip %s",
-                        clip.get("id", "<unknown>")
-                    )
+                    log.info("Migrating OpenShot 2.5 crop properties for clip %s", clip.get("id", "<unknown>"))
                     from json import loads as jl
                     effect = openshot.EffectInfo().CreateEffect("Crop")
                     effect.Id(get_app().project.generate_id())
@@ -746,6 +793,57 @@ class ProjectDataStore(JsonDataStore, UpdateInterface):
                     # Append effect JSON to clip
                     clip["effects"].append(effect_json)
 
+
+        elif openshot_version <= "3.1.1":
+
+            # Reverse alpha value for Tracker & Object Detector tracked boxes
+            log.debug("Scanning OpenShot project for legacy TrackedObjectBBox (background_alpha, stroke_alpha)")
+
+            for clip in self._data.get("clips", []):
+                for effect in clip.get("effects", []):
+                    if effect.get("name") in ["Tracker", "Object Detector"]:
+
+                        # Update display_box_text
+                        if "display_box_text" in effect:
+                            log.info("Migrating legacy Object Detector display_box_text property "
+                                     "for clip %s", clip.get("id", "<unknown>"))
+                            display_box_text_points = effect.get("display_box_text", {}).get("Points", [])
+                            for point in display_box_text_points:
+                                if "co" in point:
+                                    display_box_text = point.get("co", {}).get("Y", 1.0)
+                                    point["co"]["Y"] = 1.0 - display_box_text
+                            if not display_box_text_points:
+                                # Default to text visible
+                                display_box_text_points.append(json.loads(openshot.Point(1.0).Json()))
+
+                        # Update tracked objects
+                        objects = effect.get("objects", {})
+                        for tracked_key, tracked_data in objects.items():
+                            log.info("Migrating legacy TrackedObjectBBox alpha properties "
+                                     "for clip %s and tracked object: %s", clip.get("id", "<unknown>"), tracked_key)
+
+                            # Update Child Clip ID to Parent property (if any)
+                            child_clip_id = tracked_data.get("child_clip_id")
+                            if child_clip_id:
+                                for child_clip in self._data.get("clips", []):
+                                    if child_clip.get("id") == child_clip_id:
+                                        log.info(f"Migrating child_clip_id {child_clip_id} to parent property for tracked object {tracked_key}")
+                                        child_clip["parentObjectId"] = tracked_key
+
+                            # Update background_alpha points directly
+                            background_alpha_points = tracked_data.get("background_alpha", {}).get("Points", [])
+                            for point in background_alpha_points:
+                                if "co" in point:
+                                    background_alpha = point.get("co", {}).get("Y", 1.0)
+                                    point["co"]["Y"] = 1.0 - background_alpha
+
+                            # Update stroke_alpha points directly
+                            stroke_alpha_points = tracked_data.get("stroke_alpha", {}).get("Points", [])
+                            for point in stroke_alpha_points:
+                                if "co" in point:
+                                    stroke_alpha = point.get("co", {}).get("Y", 1.0)
+                                    point["co"]["Y"] = 1.0 - stroke_alpha
+
         # Fix default project id (if found)
         if self._data.get("id") == "T0":
             self._data["id"] = self.generate_id()
@@ -1003,7 +1101,7 @@ class ProjectDataStore(JsonDataStore, UpdateInterface):
 
         elif action.type == "update":
             # Update existing item
-            old_vals = self._set(action.key, action.values, partial_update=action.partial_update)
+            old_vals = self._set(action.key, action.values)
             action.set_old_values(old_vals)  # Save previous values to reverse this action
             self.has_unsaved_changes = True
 
