@@ -54,7 +54,7 @@ App.directive("tlClip", function ($timeout) {
         minWidth: 1,
         maxWidth: scope.clip.length * scope.pixelsPerSecond,
         start: function (e, ui) {
-          dragging = true;
+          scope.setDragging(true);
 
           // Set selections
           setSelections(scope, element, $(this).attr("id"));
@@ -91,7 +91,7 @@ App.directive("tlClip", function ($timeout) {
 
         },
         stop: function (e, ui) {
-          dragging = false;
+          scope.setDragging(false);
 
           // Show keyframe points
           element.find(".point").fadeIn(100);
@@ -135,6 +135,9 @@ App.directive("tlClip", function ($timeout) {
               // prevent less than zero
               new_left = 0.0;
               new_position -= scope.clip.start;
+            } else if (new_left >= new_right) {
+              // prevent resizing past right edge
+              new_left = new_right;
             } else {
               new_position -= delta_time;
             }
@@ -145,6 +148,9 @@ App.directive("tlClip", function ($timeout) {
             if (new_right > scope.clip.duration) {
               // prevent greater than duration
               new_right = scope.clip.duration;
+            } else if (new_right < new_left) {
+              // Prevent resizing past left edge
+              new_right = new_left;
             }
           }
 
@@ -167,7 +173,7 @@ App.directive("tlClip", function ($timeout) {
 
           // update clip in Qt (very important =)
           if (scope.Qt) {
-            timeline.update_clip_data(JSON.stringify(scope.clip), true, true, false);
+            timeline.update_clip_data(JSON.stringify(scope.clip), true, true, false, null);
           }
 
           //resize the audio canvas to match the new clip width
@@ -265,18 +271,24 @@ App.directive("tlClip", function ($timeout) {
 
       //handle draggability of clip
       element.draggable({
-        snap: ".track", // snaps to a track
-        snapMode: "inner",
-        snapTolerance: 20,
+        snap: false,
         scroll: true,
         cancel: ".effect-container,.clip_menu,.point",
         start: function (event, ui) {
           previous_drag_position = null;
-          dragging = true;
+          scope.setDragging(true);
 
           // Set selections
           setSelections(scope, element, $(this).attr("id"));
 
+          // Store initial cursor vs draggable offset
+          var elementOffset = $(this).offset();
+          var cursorOffset = {
+              left: event.pageX - elementOffset.left,
+              top: event.pageY - elementOffset.top
+          };
+          $(this).data("offset", cursorOffset);
+
           var scrolling_tracks = $("#scrolling_tracks");
           var vert_scroll_offset = scrolling_tracks.scrollTop();
           var horz_scroll_offset = scrolling_tracks.scrollLeft();
@@ -312,9 +324,12 @@ App.directive("tlClip", function ($timeout) {
 
           // Clear previous drag position
           previous_drag_position = null;
-          dragging = false;
+          scope.setDragging(false);
         },
         drag: function (e, ui) {
+          // Retrieve the initial cursor offset
+          var initialOffset = $(this).data("offset");
+
           var previous_x = ui.originalPosition.left;
           var previous_y = ui.originalPosition.top;
           if (previous_drag_position !== null) {
@@ -331,7 +346,7 @@ App.directive("tlClip", function ($timeout) {
           var y_offset = ui.position.top - previous_y;
 
           // Move the bounding box and apply snapping rules
-          var results = moveBoundingBox(scope, previous_x, previous_y, x_offset, y_offset, ui.position.left, ui.position.top);
+          var results = moveBoundingBox(scope, previous_x, previous_y, x_offset, y_offset, ui.position.left, ui.position.top, "clip", initialOffset);
           x_offset = results.x_offset;
           y_offset = results.y_offset;
 
