@@ -45,7 +45,7 @@ from classes.image_types import get_media_type
 from classes.query import File
 from classes.logger import log
 from classes.app import get_app
-from requests import get
+from classes.thumbnail import GetThumbPath
 
 import openshot
 
@@ -203,7 +203,7 @@ class FilesModel(QObject, updates.UpdateInterface):
                     thumbnail_frame = round(float(file.data['start']) * fps_float) + 1
 
                 # Get thumb path
-                thumb_icon = QIcon(self.get_thumb_path(file.id, thumbnail_frame))
+                thumb_icon = QIcon(GetThumbPath(file.id, thumbnail_frame))
             else:
                 # Audio file
                 thumb_icon = QIcon(os.path.join(info.PATH, "images", "AudioThumbnail.svg"))
@@ -295,6 +295,13 @@ class FilesModel(QObject, updates.UpdateInterface):
                 # Determine media type
                 file_data["media_type"] = get_media_type(file_data)
 
+                # Check for audio-only files
+                if file_data.get("has_audio") and not file_data.get("has_video"):
+                    # Audio-only file should match the current project size and FPS
+                    project = get_app().project
+                    file_data["width"] = project.get("width")
+                    file_data["height"] = project.get("height")
+
                 # Save new file to the project data
                 new_file = File()
                 new_file.data = file_data
@@ -307,19 +314,16 @@ class FilesModel(QObject, updates.UpdateInterface):
                 if seq_info:
                     # Update file with image sequence path & name
                     new_path = seq_info.get("path")
-                    new_file.data["name"] = os.path.basename(new_path)
 
                     # Load image sequence (to determine duration and video_length)
                     clip = openshot.Clip(new_path)
+                    new_file.data = json.loads(clip.Reader().Json())
                     if clip and clip.info.duration > 0.0:
-
                         # Update file details
-                        new_file.data["path"] = new_path
                         new_file.data["media_type"] = "video"
-                        new_file.data["duration"] = clip.Reader().info.duration
-                        new_file.data["video_length"] = "%s" % clip.Reader().info.video_length
+                        duration = new_file.data["duration"]
 
-                        if seq_info and "fps" in seq_info:
+                        if seq_info and "fps" in seq_info and "length_multiplier" in seq_info:
                             # Blender Titles specify their fps in seq_info
                             fps_num = seq_info.get("fps", {}).get("num", 25)
                             fps_den = seq_info.get("fps", {}).get("den", 1)
@@ -329,9 +333,15 @@ class FilesModel(QObject, updates.UpdateInterface):
                             fps_num = get_app().project.get("fps").get("num", 30)
                             fps_den = get_app().project.get("fps").get("den", 1)
                             log.debug("Image Sequence using project FPS: %s / %s" % (fps_num, fps_den))
-                        new_file.data["fps"] = {"num": fps_num, "den": fps_den}
 
-                        log.info(f"Imported '{new_path}' as image sequence with '{fps_num}/{fps_den}' FPS")
+                        # Adjust FPS (difference between 25 FPS and actual FPS)
+                        duration *= 25.0 / (float(fps_num) / float(fps_den))
+                        new_file.data["duration"] = duration
+                        new_file.data["fps"] = {"num": fps_num, "den": fps_den}
+                        new_file.data["video_timebase"] = {"num": fps_den, "den": fps_num}
+
+                        log.info(f"Imported '{new_path}' as image sequence with '{fps_num}/{fps_den}' FPS "
+                                 f"and '{duration}' duration")
 
                         # Remove any other image sequence files from the list we're processing
                         match_glob = "{}{}.{}".format(seq_info.get("base_name"), '[0-9]*', seq_info.get("extension"))
@@ -482,30 +492,6 @@ class FilesModel(QObject, updates.UpdateInterface):
         log.debug("Importing file list: {}".format(media_paths))
         self.add_files(media_paths, quiet=import_quietly)
 
-    def get_thumb_path(
-            self, file_id, thumbnail_frame, clear_cache=False):
-        """Get thumbnail path by invoking HTTP thumbnail request"""
-
-        # Clear thumb cache (if requested)
-        thumb_cache = ""
-        if clear_cache:
-            thumb_cache = "no-cache/"
-
-        # Connect to thumbnail server and get image
-        thumb_server_details = get_app().window.http_server_thread.server_address
-        thumb_address = "http://%s:%s/thumbnails/%s/%s/path/%s" % (
-            thumb_server_details[0],
-            thumb_server_details[1],
-            file_id,
-            thumbnail_frame,
-            thumb_cache)
-        r = get(thumb_address)
-        if r.ok:
-            # Update thumbnail path to real one
-            return r.text
-        else:
-            return ''
-
     def update_file_thumbnail(self, file_id):
         """Update/re-generate the thumbnail of a specific file"""
         file = File.get(id=file_id)
@@ -533,7 +519,7 @@ class FilesModel(QObject, updates.UpdateInterface):
                     thumbnail_frame = round(float(file.data['start']) * fps_float) + 1
 
                 # Get thumb path
-                thumb_icon = QIcon(self.get_thumb_path(file.id, thumbnail_frame, clear_cache=True))
+                thumb_icon = QIcon(GetThumbPath(file.id, thumbnail_frame, clear_cache=True))
             else:
                 # Audio file
                 thumb_icon = QIcon(os.path.join(info.PATH, "images", "AudioThumbnail.svg"))
@@ -544,6 +530,11 @@ class FilesModel(QObject, updates.UpdateInterface):
             item.setIcon(thumb_icon)
             item.setText(name)
 
+            # Update display name
+            text_index = id_index.sibling(id_index.row(), 1)
+            item = m.itemFromIndex(text_index)
+            item.setText(name)
+
             # Emit signal when model is updated
             self.ModelRefreshed.emit()
 
