@@ -165,6 +165,7 @@ class Preferences(QDialog):
                     # Create tab widget and layout
                     layout = QVBoxLayout()
                     tabWidget = QWidget(self)
+                    tabWidget.setObjectName("PreferencePanel")
                     tabWidget.setSizePolicy(QSizePolicy.Preferred, QSizePolicy.Preferred)
                     tabWidget.setLayout(layout)
                     scroll_area.setWidget(tabWidget)
@@ -255,6 +256,7 @@ class Preferences(QDialog):
 
                     # create spinner
                     widget = QComboBox()
+                    widget.setSizeAdjustPolicy(QComboBox.AdjustToMinimumContentsLengthWithIcon)
 
                     # Get values
                     value_list = param["values"]
@@ -263,16 +265,23 @@ class Preferences(QDialog):
                         value_list = []
                         # Loop through profiles
                         for profile_folder in [info.USER_PROFILES_PATH, info.PROFILES_PATH]:
-                            for file in os.listdir(profile_folder):
+                            for file in reversed(sorted(os.listdir(profile_folder))):
                                 # Load Profile and append description
                                 profile_path = os.path.join(profile_folder, file)
+                                if os.path.isdir(profile_path):
+                                    continue
                                 profile = openshot.Profile(profile_path)
+                                profile_lbl = f"{profile.info.description} ({profile.info.width}x{profile.info.height})"
                                 value_list.append({
-                                    "name": profile.info.description,
+                                    "name": profile_lbl,
                                     "value": profile.info.description
                                     })
-                        # Sort profile list
-                        value_list.sort(key=operator.itemgetter("name"))
+
+                        # Add test button
+                        extraWidget = QPushButton()
+                        extraWidget.setToolTip(_("Search Profiles"))
+                        extraWidget.setIcon(QIcon(":/icons/Humanity/mimes/16/video-x-generic.svg"))
+                        extraWidget.clicked.connect(functools.partial(self.btnBrowseProfiles_clicked, widget))
 
                     # Overwrite value list (for audio device list dropdown)
                     if param["setting"] == "playback-audio-device":
@@ -280,10 +289,21 @@ class Preferences(QDialog):
                         # Loop through audio devices
                         value_list.append({"name": "Default", "value": ""})
                         for audio_device in get_app().window.preview_thread.player.GetAudioDeviceNames():
+                            # Text:  Type first, then device name  (i.e. "ALSA: PulseAudio Sound Server")
+                            # Value: Name first, ||, then device type  (i.e. "PulseAudio Sound Server||ALSA")
                             value_list.append({
                                 "name": "%s: %s" % (audio_device[1], audio_device[0]),
-                                "value": audio_device[0],
-                                })
+                                "value": "%s||%s" % (audio_device[0], audio_device[1])
+                            })
+
+                    # Overwrite value list (for theme names)
+                    if param["setting"] == "theme":
+                        from themes.manager import ThemeName
+                        value_list = []
+                        for theme_name in ThemeName.get_sorted_theme_names():
+                            value_list.append({
+                                "name": _(theme_name), "value": theme_name
+                            })
 
                     # Overwrite value list (for language dropdown)
                     if param["setting"] == "default-language":
@@ -336,8 +356,8 @@ class Preferences(QDialog):
                     # Add normal values
                     box_index = 0
                     for value_item in value_list:
-                        k = value_item["name"]
-                        v = value_item["value"]
+                        k = value_item.get("name")
+                        v = value_item.get("value")
                         i = value_item.get("icon", None)
 
                         # Translate dropdown item (if needed)
@@ -544,9 +564,62 @@ class Preferences(QDialog):
         if param["setting"] == "graca_number_en":
             openshot.Settings.Instance().HW_EN_DEVICE_SET = int(value)
 
+        if param["setting"] == "theme":
+            # Apply selected theme to UI
+            if get_app().theme_manager:
+                get_app().theme_manager.apply_theme(value)
+
         # Check for restart
         self.check_for_restart(param)
 
+    def btnBrowseProfiles_clicked(self, widget):
+        """Search profile button clicked"""
+        # Get current selection profile object
+        profile_description = widget.currentData()
+
+        # Find matching profile path
+        matching_profile_path = None
+        for profile_folder in [info.USER_PROFILES_PATH, info.PROFILES_PATH]:
+            for file in reversed(sorted(os.listdir(profile_folder))):
+                # Load Profile and append description
+                matching_profile_path = os.path.join(profile_folder, file)
+                if os.path.isdir(matching_profile_path):
+                    continue
+                profile = openshot.Profile(matching_profile_path)
+                if profile.info.description == profile_description:
+                    break
+
+        # Load matching profile
+        current_profile = openshot.Profile(matching_profile_path)
+
+        # Show dialog (init to current selection)
+        from windows.profile import Profile
+        log.debug("Showing profile dialog")
+        win = Profile(current_profile.Key())
+        # Run the dialog event loop - blocking interaction on this window during this time
+        result = win.exec_()
+
+        profile = win.selected_profile
+        if result == QDialog.Accepted and profile:
+
+            # select the project's current profile
+            profile_index = self.getVideoProfileIndex(widget, profile)
+            if profile_index != -1:
+                # Re-select project profile (if found in list)
+                widget.setCurrentIndex(profile_index)
+            else:
+                # Previous profile not in list, so
+                # default to first profile in list
+                widget.setCurrentIndex(0)
+
+    def getVideoProfileIndex(self, widget, profile):
+        """Get the index of a profile name or profile key (-1 if not found)"""
+        for index in range(widget.count()):
+            combo_profile_description = widget.itemData(index)
+            if profile.info.description == combo_profile_description:
+                return index
+        return -1
+
     def testHardwareDecode(self, widget, param, btn):
         """Test specific settings for hardware decode"""
         all_decoders = param.get("values", [])
