@@ -33,17 +33,18 @@ import sys
 import functools
 import subprocess
 import tempfile
+import threading
 
 # TODO: Is there a defusedxml substitute for getDOMImplementation?
 # Is one even necessary, or is it safe to use xml.dom.minidom for that?
 from xml.dom import minidom
 
-from PyQt5.QtCore import Qt, pyqtSlot, QTimer
-from PyQt5 import QtGui
+from PyQt5.QtCore import Qt, pyqtSlot, QTimer, pyqtSignal
+from PyQt5.QtGui import QFontDatabase, QColor, QIcon, QFont, QFontInfo
 from PyQt5.QtWidgets import (
-    QWidget, QGraphicsScene,
+    QWidget,
     QMessageBox, QDialog, QColorDialog, QFontDialog,
-    QPushButton, QLineEdit, QLabel
+    QPushButton, QLineEdit, QLabel, QDialogButtonBox
 )
 
 import openshot
@@ -52,7 +53,6 @@ from classes import info, ui_util
 from classes.logger import log
 from classes.app import get_app
 from classes.metrics import track_metric_screen
-from windows.views.titles_listview import TitlesListView
 from windows.color_picker import ColorPicker
 from classes.style_tools import style_to_dict, dict_to_style, set_if_existing
 from windows.views.titles_listview import TitlesListView
@@ -63,15 +63,19 @@ class TitleEditor(QDialog):
 
     # Path to ui file
     ui_path = os.path.join(info.PATH, 'windows', 'ui', 'title-editor.ui')
+    thumbnailReady = pyqtSignal(object)
 
     def __init__(self, *args, edit_file_path=None, duplicate=False, **kwargs):
 
         # Create dialog class
         super().__init__(*args, **kwargs)
 
+        # Init font DB
+        self.font_db = QFontDatabase()
+
         # A timer to pause until user input stops before updating the svg
         self.update_timer = QTimer(self)
-        self.update_timer.setInterval(300)
+        self.update_timer.setInterval(50)
         self.update_timer.setSingleShot(True)
         self.update_timer.timeout.connect(self.save_and_reload)
 
@@ -86,6 +90,20 @@ class TitleEditor(QDialog):
         # Init UI
         ui_util.init_ui(self)
 
+        # Set up the buttons
+        self.buttonBox = QDialogButtonBox(QDialogButtonBox.Save | QDialogButtonBox.Cancel)
+        self.saveButton = self.buttonBox.button(QDialogButtonBox.Save)
+        self.cancelButton = self.buttonBox.button(QDialogButtonBox.Cancel)
+
+        # Set object names (for theme styles)
+        self.saveButton.setObjectName("acceptButton")
+        self.cancelButton.setObjectName("cancelButton")
+        self.layout().addWidget(self.buttonBox)
+
+        # Connect the buttons
+        self.saveButton.clicked.connect(self.accept)
+        self.cancelButton.clicked.connect(self.reject)
+
         # Track metrics
         track_metric_screen("title-screen")
 
@@ -97,12 +115,13 @@ class TitleEditor(QDialog):
             log.debug('Removing custom LD_LIBRARY_PATH from environment variables when launching Inkscape')
 
         # Initialize variables
+        self.is_thread_busy = False
         self.template_name = ""
         imp = minidom.getDOMImplementation()
         self.xmldoc = imp.createDocument(None, "any", None)
 
-        self.bg_color_code = QtGui.QColor(Qt.black)
-        self.font_color_code = QtGui.QColor(Qt.white)
+        self.bg_color_code = QColor(Qt.black)
+        self.font_color_code = QColor(Qt.white)
 
         self.bg_style_string = ""
         self.title_style_string = ""
@@ -110,17 +129,18 @@ class TitleEditor(QDialog):
 
         self.font_weight = 'normal'
         self.font_style = 'normal'
-        self.font_size_ratio = 1
+        self.font_size_ratio = 1.0
 
         self.new_title_text = ""
         self.sub_title_text = ""
         self.subTitle = False
 
         self.display_name = ""
-        self.font_family = "Bitstream Vera Sans"
         self.tspan_nodes = None
 
-        self.qfont = QtGui.QFont(self.font_family)
+        self.default_font_family = "DejaVu Sans"
+        self.font_family = self.default_font_family
+        self.qfont = self.get_font(self.font_family)
 
         # Add titles list view
         self.titlesView = TitlesListView(parent=self, window=self)
@@ -129,6 +149,9 @@ class TitleEditor(QDialog):
         # Disable Save button on window load
         self.buttonBox.button(self.buttonBox.Save).setEnabled(False)
 
+        # Connect thumbnail listener
+        self.thumbnailReady.connect(self.display_pixmap)
+
         # If editing existing title svg file
         if self.edit_file_path:
             # Hide list of templates
@@ -143,6 +166,37 @@ class TitleEditor(QDialog):
             # Display image (slight delay to allow screen to be shown first)
             QTimer.singleShot(50, self.display_svg)
 
+    def get_font(self, requested_font_name):
+        """
+        Checks for a valid font name and returns a QFont object.
+        If the requested font is not available, it falls back to common fonts.
+
+        :param requested_font_name: The name of the font to search for.
+        :return: QFont object of either the requested font or the first available fallback font.
+        """
+        available_fonts = self.font_db.families()
+        fallback_fonts = ['DejaVu Sans', 'Liberation Sans', 'Noto Sans', 'FreeSans',
+                          'Ubuntu', 'Cantarell', 'Open Sans', 'Sans-serif', 'Arial']
+
+        # Check if the requested font is available
+        available_fonts = self.font_db.families()
+        for font in available_fonts:
+            if requested_font_name in font:
+                return QFont(font)
+
+        # Try fallback fonts
+        for fallback in fallback_fonts:
+            for font in available_fonts:
+                if fallback in font:
+                    return QFont(font)
+
+        # Return the default font
+        return QFont()
+
+    def display_pixmap(self, display_pixmap):
+        """Display pixmap of SVG on UI thread"""
+        self.lblPreviewLabel.setPixmap(display_pixmap)
+
     def txtLine_changed(self, txtWidget):
 
         # Loop through child widgets (and remove them)
@@ -191,10 +245,10 @@ class TitleEditor(QDialog):
         clip.Close()
 
         # Attempt to load saved thumbnail
-        display_pixmap = QtGui.QIcon(tmp_filename).pixmap(self.lblPreviewLabel.size())
+        display_pixmap = QIcon(tmp_filename).pixmap(self.lblPreviewLabel.size())
 
         # Display temp image
-        self.lblPreviewLabel.setPixmap(display_pixmap)
+        self.thumbnailReady.emit(display_pixmap)
 
         # Remove temporary file
         os.unlink(tmp_filename)
@@ -222,10 +276,8 @@ class TitleEditor(QDialog):
         self.tspan_nodes = self.xmldoc.getElementsByTagName('tspan')
 
         # Reset default font
-        self.font_family = "Bitstream Vera Sans"
-        if self.qfont:
-            del self.qfont
-        self.qfont = QtGui.QFont(self.font_family)
+        self.font_family = self.default_font_family
+        self.qfont = QFont(self.get_font(self.font_family))
 
         # Loop through child widgets (and remove them)
         for child in self.settingsContainer.children():
@@ -297,7 +349,7 @@ class TitleEditor(QDialog):
             title_text.append(text)
 
             # Set font size (for possible font dialog)
-            s = node.attributes["style"].value
+            s = node.getAttribute("style")
             ard = style_to_dict(s)
             fs = ard.get("font-size")
             if fs and fs.endswith("px"):
@@ -311,11 +363,15 @@ class TitleEditor(QDialog):
             label.setToolTip(label_line_text)
 
             # create text editor for each text element in title
-            widget = QLineEdit(_(text))
+            widget = QLineEdit(text)
             widget.setFixedHeight(28)
             widget.textChanged.connect(functools.partial(self.txtLine_changed, widget))
             layout.addRow(label, widget)
 
+        # Set font
+        self.set_font_attributes(self.qfont.family())
+        self.writeToFile(self.xmldoc)
+
         # Add Font button
         label = QLabel(_("Font:"))
         label.setToolTip(_("Font:"))
@@ -375,10 +431,21 @@ class TitleEditor(QDialog):
 
     def save_and_reload(self):
         """Something changed, so update temp SVG and redisplay"""
+        if not self.is_thread_busy:
+            t = threading.Thread(target=self.save_and_reload_thread, daemon=True)
+            t.start()
+        else:
+            # Keep retrying until we succeed
+            self.update_timer.start()
+
+    def save_and_reload_thread(self):
+        """Run inside thread, to update and display new SVG - so we don't block the main UI thread"""
+        self.is_thread_busy = True
         self.writeToFile(self.xmldoc)
         self.display_svg()
+        self.is_thread_busy = False
 
-    @pyqtSlot(QtGui.QColor)
+    @pyqtSlot(QColor)
     def color_callback(self, save_fn, refresh_fn, color):
         """Update SVG color after user selection"""
         if not color or not color.isValid():
@@ -388,14 +455,14 @@ class TitleEditor(QDialog):
         self.update_timer.start()
 
     @staticmethod
-    def best_contrast(bg: QtGui.QColor) -> QtGui.QColor:
+    def best_contrast(bg: QColor) -> QColor:
         """Choose text color for best contrast against a background"""
         colrgb = bg.getRgbF()
         # Compute perceptive luminance of background color
         lum = (0.299 * colrgb[0] + 0.587 * colrgb[1] + 0.114 * colrgb[2])
         if (lum < 0.5):
-            return QtGui.QColor(Qt.white)
-        return QtGui.QColor(Qt.black)
+            return QColor(Qt.white)
+        return QColor(Qt.black)
 
     def btnFontColor_clicked(self):
         app = get_app()
@@ -442,14 +509,15 @@ class TitleEditor(QDialog):
         # Update SVG font
         if ok and font is not oldfont:
             self.qfont = font
-            fontinfo = QtGui.QFontInfo(font)
-            oldfontinfo = QtGui.QFontInfo(oldfont)
+            fontinfo = QFontInfo(font)
+            oldfontinfo = QFontInfo(oldfont)
             self.font_family = fontinfo.family()
             self.font_style = fontinfo.styleName()
             self.font_weight = fontinfo.weight()
-            if (oldfontinfo.pixelSize() > 0):
+            self.font_size_ratio = 1.0
+            if oldfontinfo.pixelSize() > 0:
                 self.font_size_ratio = fontinfo.pixelSize() / oldfontinfo.pixelSize()
-            self.set_font_style()
+            self.set_font_attributes(self.font_family, self.font_style, self.font_size_ratio)
             self.update_timer.start()
 
     def update_font_color_button(self):
@@ -459,7 +527,7 @@ class TitleEditor(QDialog):
         for node in self.text_nodes + self.tspan_nodes:
 
             # Get the value in the style attribute and turn into a dict
-            s = node.attributes["style"].value
+            s = node.getAttribute("style")
             ard = style_to_dict(s)
             # Get fill color or default to white
             color = ard.get("fill", "#FFF")
@@ -473,7 +541,7 @@ class TitleEditor(QDialog):
             # Get opacity or default to opaque
             opacity = float(ard.get("opacity", 1.0))
 
-            color = QtGui.QColor(color)
+            color = QColor(color)
             text_color = self.best_contrast(color)
             # Set the color of the button, ignoring alpha
             self.btnFontColor.setStyleSheet(
@@ -503,7 +571,7 @@ class TitleEditor(QDialog):
                         for stop_node in ref_node.childNodes:
                             if stop_node.nodeName == "stop":
                                 # get color from stop
-                                ard = style_to_dict(stop_node.attributes["style"].value)
+                                ard = style_to_dict(stop_node.getAttribute("style"))
                                 if "stop-color" in ard:
                                     return ard.get("stop-color")
         return ""
@@ -513,14 +581,14 @@ class TitleEditor(QDialog):
 
         if self.rect_node:
             # All backgrounds should be the first (index 0) rect tag in the svg
-            s = self.rect_node[0].attributes["style"].value
+            s = self.rect_node[0].getAttribute("style")
             ard = style_to_dict(s)
 
             # Get fill color or default to black + full opacity
             color = ard.get("fill", "#000")
             opacity = float(ard.get("opacity", 1.0))
 
-            color = QtGui.QColor(color)
+            color = QColor(color)
             text_color = self.best_contrast(color)
 
             # Set the colors of the button, ignoring opacity
@@ -533,19 +601,24 @@ class TitleEditor(QDialog):
             self.bg_color_code = color
             log.debug("Set color of background-color button to %s", color.name())
 
-    def set_font_style(self):
+    def set_font_attributes(self, font_family, font_style=None, font_size_ratio=0):
         '''sets the font properties'''
+        log.debug(f"Setting font-family to {font_family}.")
+
         # Loop through each TEXT element
         for text_child in self.text_nodes + self.tspan_nodes:
             # set the style elements for the main text node
-            s = text_child.attributes["style"].value
+            s = text_child.getAttribute("style")
             ard = style_to_dict(s)
-            set_if_existing(ard, "font-style", self.font_style)
-            set_if_existing(ard, "font-family", f"'{self.font_family}'")
-            new_font_size_pixel = 0
-            if 'font-size' in ard:
-                new_font_size_pixel = self.font_size_ratio * float(ard['font-size'][:-2])
-            set_if_existing(ard, "font-size", f"{new_font_size_pixel}px")
+            if font_family:
+                set_if_existing(ard, "font-family", f"'{font_family}'")
+            if font_style:
+                set_if_existing(ard, "font-style", font_style)
+            if font_size_ratio:
+                new_font_size_pixel = 100
+                if 'font-size' in ard:
+                    new_font_size_pixel = font_size_ratio * float(ard['font-size'][:-2])
+                set_if_existing(ard, "font-size", f"{new_font_size_pixel}px")
             self.title_style_string = dict_to_style(ard)
 
             # set the text node
@@ -557,7 +630,7 @@ class TitleEditor(QDialog):
 
         if self.rect_node:
             # Turn the style attribute into a dict for modification
-            s = self.rect_node[0].attributes["style"].value
+            s = self.rect_node[0].getAttribute("style")
             ard = style_to_dict(s)
             ard.update({
                 "fill": color,
@@ -572,7 +645,7 @@ class TitleEditor(QDialog):
         # Loop through each TEXT element
         for text_child in self.text_nodes + self.tspan_nodes:
             # SET TEXT PROPERTIES
-            s = text_child.attributes["style"].value
+            s = text_child.getAttribute("style")
             ard = style_to_dict(s)
             ard.update({
                 "fill": color,
@@ -624,21 +697,27 @@ class TitleEditor(QDialog):
 
     def btnAdvanced_clicked(self):
         """Use an external editor to edit the image"""
-        # Get editor executable from settings
+        # Get editor executable from settings (or placeholder text)
+        _ = self.app._tr
         s = get_app().get_settings()
-        prog = s.get("title_editor")
-        # Store filename field to display on reload
+        prog = s.get("title_editor").strip()
+        setting_name = _("Advanced Title Editor (path)")
+        prog_warning = ""
+        if prog.strip():
+            prog_warning = f": [{prog}]"
+
+        # Get filename field to display on reload
         filename_text = self.txtFileName.text().strip()
         try:
             # launch advanced title editor
             log.info("Advanced title editor command: %s", str([prog, self.filename]))
             p = subprocess.Popen([prog, self.filename], env=self.env)
+
             # wait for process to finish, then update preview
             p.communicate()
             self.load_svg_template(filename_field=filename_text)
             self.display_svg()
+
         except OSError:
-            _ = self.app._tr
-            msg = QMessageBox(self)
-            msg.setText(_("Please install %s to use this function" % prog))
-            msg.exec_()
+            QMessageBox.warning(self, _("Settings Error"),
+                                _("Please install %s to use this function" % f"<b>{setting_name}{prog_warning}</b>"))
