@@ -38,7 +38,7 @@ import openshot  # Python module for libopenshot (required video editing module
 from classes import updates
 from classes.app import get_app
 from classes.query import Clip, Track, Transition, Marker
-from themes.manager import ThemeManager
+from classes.logger import log
 
 
 class ZoomSlider(QWidget, updates.UpdateInterface):
@@ -46,6 +46,10 @@ class ZoomSlider(QWidget, updates.UpdateInterface):
 
     # This method is invoked by the UpdateManager each time a change happens (i.e UpdateInterface)
     def changed(self, action):
+        # Ignore changes that don't affect this
+        if action and len(action.key) >= 1 and action.key[0].lower() in ["files", "history", "profile"]:
+            return
+
         # Clear previous rects
         self.clip_rects.clear()
         self.clip_rects_selected.clear()
@@ -108,10 +112,14 @@ class ZoomSlider(QWidget, updates.UpdateInterface):
         event.accept()
 
         # Get theme colors
-        theme = ThemeManager().get_current_theme()
-        if not theme:
-            return
-        playhead_color = theme.get_color(".zoom_slider_playhead", "background-color")
+        if get_app().theme_manager:
+            theme = get_app().theme_manager.get_current_theme()
+            if not theme:
+                log.warning("No theme loaded yet. Skip rendering zoom slider widget.")
+                return
+            playhead_color = theme.get_color(".zoom_slider_playhead", "background-color")
+        else:
+            log.warning("No ThemeManager loaded yet. Skip rendering zoom slider widget.")
 
         # Paint timeline preview on QWidget
         painter = QPainter(self)
